==> 1.0.1.tar.gz: lib/geidea_primary_button_outlines.dart <==
import 'package:flutter/material.dart';
import 'package:geideadesignframework/style_config.dart';

import 'style_config.dart';

class GeideaPrimaryButtonOutlined extends StatefulWidget {
  GeideaPrimaryButtonOutlined(
      {Key key,
        @required this.text,
        @required this.clickCallback,
        this.isDisabled = false,
        this.preTextWidget,
        this.postTextWidget,
        this.textColor,
        this.backgroundColor,
        this.disabledColor,
        this.borderRadius,
        this.fontSize,
        this.borderWidth,
        this.borderColor,
        this.padding,
        this.letterSpacing,
        this.fontWeight})
      : super(key: key);

  final String text;
  final bool isDisabled;
  final VoidCallback clickCallback;
  final Widget preTextWidget;
  final Widget postTextWidget;
  final Color textColor;
  final Color backgroundColor;
  final Color disabledColor;
  final double borderRadius;
  final double fontSize;
  final double borderWidth;
  final Color borderColor;
  final double letterSpacing;
  final EdgeInsets padding;
  final FontWeight fontWeight;

  @override
  _GeideaPrimaryButtonOutlinedState createState() => _GeideaPrimaryButtonOutlinedState();
}

class _GeideaPrimaryButtonOutlinedState extends State<GeideaPrimaryButtonOutlined> {
  bool _isButtonDisabled;

  @override
  void initState() {
    _isButtonDisabled = _isButtonDisabled;
  }

  void _disableButton() {
    setState(() {
      _isButtonDisabled = true;
    });
  }

  @override
  Widget build(BuildContext context) {
    return IgnorePointer(
      ignoring: _isButtonDisabled,
      child: RawMaterialButton(
          onPressed: () {
            if (!_isButtonDisabled) widget.clickCallback();
          },
          padding: widget.padding ?? styleConfig.mainButtonPadding,
          shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(
                  widget.borderRadius ?? styleConfig.borderRadius),
              side: BorderSide(
                  color: widget.borderColor ?? styleConfig.theme.primaryColor,
                  width: 1,
                  style: BorderStyle.solid
              )
          ),
          elevation: 0,
          disabledElevation: 0,
//          fillColor: Colors.transparent,
//          highlightColor: widget.backgroundColor != null ?  widget.backgroundColor.withOpacity(0.3) :
//          styleConfig.theme.primaryColor.withOpacity(0.3),
          child: Row(mainAxisAlignment: MainAxisAlignment.center, children: <
              Widget>[
            widget.preTextWidget == null ? Container() : widget.preTextWidget,
            Text(
              widget.text,
              style: TextStyle(
                fontFamily: styleConfig.fontFamily,
                fontSize: widget.fontSize ?? styleConfig.getFontSize('button'),
                fontWeight:
                widget.fontWeight ?? styleConfig.mainButtonFontWeight,
                letterSpacing:
                widget.letterSpacing ?? styleConfig.letterSpacing,
                color: widget.textColor ?? styleConfig.theme.primaryColor,
              ),
            ),
            widget.postTextWidget == null ? Container() : widget.postTextWidget,
          ])),
    );
  }
}

==> 1.0.3.tar.gz: lib/geidea_primary_button_outlines.dart <==
import 'package:flutter/material.dart';
import 'package:geideadesignframework/style_config.dart';

import 'style_config.dart';

class GeideaPrimaryButtonOutlined extends StatefulWidget {
  GeideaPrimaryButtonOutlined(
      {Key key,
        @required this.text,
        @required this.clickCallback,
        this.isDisabled = false,
        this.preTextWidget,
        this.postTextWidget,
        this.textColor,
        this.backgroundColor,
        this.disabledColor,
        this.borderRadius,
        this.fontSize,
        this.borderWidth,
        this.borderColor,
        this.padding,
        this.letterSpacing,
        this.fontWeight})
      : super(key: key);

  final String text;
  final bool isDisabled;
  final VoidCallback clickCallback;
  final Widget preTextWidget;
  final Widget postTextWidget;
  final Color textColor;
  final Color backgroundColor;
  final Color disabledColor;
  final double borderRadius;
  final double fontSize;
  final double borderWidth;
  final Color borderColor;
  final double letterSpacing;
  final EdgeInsets padding;
  final FontWeight fontWeight;

  @override
  _GeideaPrimaryButtonOutlinedState createState() => _GeideaPrimaryButtonOutlinedState();
}

class _GeideaPrimaryButtonOutlinedState extends State<GeideaPrimaryButtonOutlined> {


  @override
  Widget build(BuildContext context) {
    return IgnorePointer(
      ignoring: widget.isDisabled,
      child: RawMaterialButton(
          onPressed: () {
            if (!widget.isDisabled) widget.clickCallback();
          },
          padding: widget.padding ?? styleConfig.mainButtonPadding,
          shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(
                  widget.borderRadius ?? styleConfig.borderRadius),
              side: BorderSide(
                  color: widget.borderColor ?? styleConfig.theme.primaryColor,
                  width: 1,
                  style: BorderStyle.solid
              )
          ),
          elevation: 0,
          disabledElevation: 0,
//          fillColor: Colors.transparent,
//          highlightColor: widget.backgroundColor != null ?  widget.backgroundColor.withOpacity(0.3) :
//          styleConfig.theme.primaryColor.withOpacity(0.3),
          child: Row(mainAxisAlignment: MainAxisAlignment.center, children: <
              Widget>[
            widget.preTextWidget == null ? Container() : widget.preTextWidget,
            Text(
              widget.text,
              style: TextStyle(
                fontFamily: styleConfig.fontFamily,
                fontSize: widget.fontSize ?? styleConfig.getFontSize('button'),
                fontWeight:
                widget.fontWeight ?? styleConfig.mainButtonFontWeight,
                letterSpacing:
                widget.letterSpacing ?? styleConfig.letterSpacing,
                color: widget.textColor ?? styleConfig.theme.primaryColor,
              ),
            ),
            widget.postTextWidget == null ? Container() : widget.postTextWidget,
          ])),
    );
  }
}
